@@ -74,7 +74,7 @@ from datetime import datetime
 from cronlog import CronLog
 
 __pkgname__ = 'python-crontab'
-__version__ = '1.4'
+__version__ = '1.4.1'
 
 ITEMREX = re.compile('^\s*([^@#\s]+)\s+([^@#\s]+)\s+([^@#\s]+)' +
     '\s+([^@#\s]+)\s+([^@#\s]+)\s+([^#\n]*)(\s+#\s*([^\n]*)|$)')
@@ -117,7 +117,7 @@ WinOS = platform.system() == 'Windows'
 SunOS = not WinOS and (os.uname()[0] == "SunOS" or os.getenv('SunOS_TEST'))
 CRONCMD = "/usr/bin/crontab"
 if sys.argv[0].startswith('test_'):
-    CRONCMD = './crontest'
+    CRONCMD = './data/crontest'
 
 if py3:
     unicode = str
